@@ -1,19 +1,88 @@
 import os
 import re
+import sys
 import json
 import uuid
 import time
+import spacy
+import logging
 import requests
 import pandas as pd
 import numpy as np
 import traceback
 from sys import exc_info
+
 pd.options.mode.chained_assignment = None
 
 BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
 ERR_SYS = "System error: "
 RETRIES = int(os.environ["RETRIES"])
 
+logger = logging.getLogger(__name__)
+
+
+class Features:
+    """
+    Clase para el procesamiento de texto con spacy
+    """
+
+    def __init__(self):
+        """
+        Inicialización de la clase
+        """
+        print('\nLoading Spacy es model...')
+        nlp_model = spacy.load('es_core_news_md',
+                               disable=['ner', 'parser'])  # disabling Named Entity Recognition for speed
+        print('Done.\n')
+        self.nlp_model = nlp_model
+
+        self.bad_words = ['de', 'que', 'la', 'los', 'el', 'las']
+
+    def pos_tags(self, input_txt):
+        """
+        Funcion para generar las features de las palabras enviadas con el parametro input_txt
+        :param input_txt: String to get the features from.
+        :return:dict: keys -> tokens, lemmas and part of speech tags.
+        """
+        method_name = "pos_tags"
+        self.input_txt = input_txt
+        words = []
+        lemmas = []
+        pos_tags = []
+        if type(input_txt) != str:
+            print('ERROR: Input is not a string.')
+            print(f'Class: {self.__str__()}\nMethod: {method_name}')
+            logger.info(f"Se produjo error al no llegar datos en {method_name}")
+        else:
+            bad_words = self.bad_words
+            nlp_model = self.nlp_model
+            try:
+                doc = nlp_model(self.input_txt.lower())
+                features = [(token.text.replace('xxhashtagsignxx', '#').replace('xxatsignxx', '@'),
+                             token.lemma_.replace('xxhashtagsignxx', '#').replace('xxatsignxx', '@'),
+                             token.pos_) for token in doc if token.text not in bad_words and len(token.text) > 1]
+                for feat in features:
+                    if feat[2] in {'PROPN', 'NOUN', 'VERB', 'ADJ'}:
+                        words.append(feat[0])
+                        lemmas.append(feat[1])
+                        pos_tags.append(feat[2])
+                logger.info(f"Se generaron los datos para {method_name}")
+            except Exception as e:
+                print(e)
+                error_1 = sys.exc_info()[0]
+                print(ERR_SYS + str(error_1))
+                print(f'Class: {self.__str__()}\nMethod: {method_name}')
+                logger.info(f"Se produjo error al procesar los datos en {method_name}")
+                words.clear()
+                lemmas.clear()
+                pos_tags.clear()
+        out_dict = {
+            'words': words,
+            'lemmas': lemmas,
+            'pos_tags': pos_tags
+        }
+        return out_dict
+
 
 class CleanText:
     """
@@ -320,3 +389,46 @@ class sendData:
                 df_output_all = pd.DataFrame(columns=df_b2a.columns)
 
         return df_output_all
+
+# class Features:
+#     def __init__(self):
+#         """
+#         This functions loads the spacy model for spanish.
+#
+#         """
+#
+#     def pos_tags(self, input_txt):
+#         """
+#         This functions get the features of the words in the input_txt parameter.
+#
+#         Parameters
+#         ----------
+#         input_txt:
+#             type: str
+#             String to get the features from.
+#
+#         Returns
+#         -------
+#         dict: keys -> tokens, lemmas and part of speech tags.
+#         i
+#         """
+#         method_name = "pos_tags"
+#         self.input_txt = input_txt
+#         if type(input_txt) != str:
+#             print("ERROR: Input is not a string.")
+#             print(f"Class: {self.__str__()}\nMethod: {method_name}")
+#             self.input_txt = ""
+#
+#         try:
+#             out_dict = send_to_model(
+#                 data={"value": input_txt},
+#                 ms_models_path=URL_MS_MODELOS + "/models_reg/features/pos_tags",
+#             )
+#         except Exception as e_1:
+#             print(e_1)
+#             error_1 = sys.exc_info()[0]
+#             print(ERR_SYS + str(error_1))
+#             print(f"Class: {self.__str__()}\nMethod: {method_name}")
+#             out_dict = {"words": [], "lemmas": [], "pos_tags": []}
+#
+#         return out_dict
